@@ -9,11 +9,11 @@ import sys
 import os
 import json
 import threading
-import pty 
+import pty
 import collections
 import subprocess
 import signal
-from typing import ( 
+from typing import (
     DefaultDict,
     Optional,
     Tuple,
@@ -24,12 +24,11 @@ from typing import (
     Any,
 )
 from logging.handlers import DatagramHandler
-from websocket_server import WebsocketServer #type: ignore
+from websocket_server import WebsocketServer  # type: ignore
 from py2cfg.builder import CFGBuilder
 from py2cfg._source_db import CFG_Database
 
 
-
 # --- Forward type declarations --- #
 # Stores pid of debugger/this process
 _pid: int
@@ -38,8 +37,8 @@ _pid: int
 _child_pid: int
 
 LineCache = DefaultDict[
-    Tuple[str, str, int], # filename, funcname, stacklevel
-    List[int],            # list of executed lines
+    Tuple[str, str, int],  # filename, funcname, stacklevel
+    List[int],  # list of executed lines
 ]
 
 logger = logging.getLogger(__name__)
@@ -64,15 +63,14 @@ def new_client(client, server):
         calls=True,
         cleanup=True,
         directory=os.path.join(os.environ["PY2CFG_SERVE_AT"], "cfg"),
-        build_keys=True
+        build_keys=True,
     )
     logger.debug(f"Build key at {_path}")
     server.send_message(
         client,
-        json.dumps({
-            "type": "key",
-            "filepath": os.path.join("cfg", "key.svg"),
-        })
+        json.dumps(
+            {"type": "key", "filepath": os.path.join("cfg", "key.svg"),}
+        ),
     )
 
     with _cond:
@@ -83,6 +81,7 @@ def client_left(client, server):
     # How to gracefully shutdown pudb when browser tab is closed?
     pass
 
+
 def message_received(client, server, message):
     """Called when SVG link is clicked ?"""
 
@@ -94,6 +93,7 @@ server.set_fn_message_received(message_received)
 
 _entry_frame = None
 
+
 def _set_entry_frame(frame, name):
     global _entry_frame
     if frame.f_code.co_filename == name and _entry_frame is None:
@@ -127,9 +127,8 @@ def _get_stack_level(current_frame):
         else:
             break
         frame_sl -= 1
-    
-    return current_frame.f_locals[LOCAL_SL]
 
+    return current_frame.f_locals[LOCAL_SL]
 
 
 # --- Databases --- #
@@ -140,12 +139,12 @@ def wrap_user_call(func, entry):
     def user_call(dbg, _frame, argument_list):
         if _pid == os.getpid():
             _set_entry_frame(_frame, entry)
-          
-                
-               
+
         return func(dbg, _frame, argument_list)
+
     return user_call
 
+
 _child_pid = None  # type: ignore
 
 
@@ -154,56 +153,59 @@ def get_future_id():
 
 
 class ExecData(tuple):
-
     @property
     def filename(self):
         return self[0]
-    
+
     @property
     def funcname(self):
         return self[1]
-    
+
     @property
     def lineno(self):
         return self[2]
-    
+
     @property
     def event(self):
         return self[3]
-    
+
     @property
     def stack_level(self):
         return self[4]
 
     @classmethod
-    def create(cls,
-        filename:str,
+    def create(
+        cls,
+        filename: str,
         funcname: str,
         lineno: int,
         event: str,
         stacklevel: int,
     ):
         return cls((filename, funcname, lineno, event, stacklevel))
-        
+
     @classmethod
     def from_frame(cls, frame, event):
-        return cls((
-            frame.f_code.co_filename,
-            frame.f_code.co_name,
-            frame.f_lineno,
-            event,
-            _get_stack_level(frame),
-        ))
+        return cls(
+            (
+                frame.f_code.co_filename,
+                frame.f_code.co_name,
+                frame.f_lineno,
+                event,
+                _get_stack_level(frame),
+            )
+        )
+
 
 def trace_create(f_id, queue_object):
     def trace(frame, event, args):
         queue_object.put(ExecData.from_frame(frame, event))
         return trace
+
     return trace
 
 
 class FrameWrapper:
-    
     def __init__(self, frame, rel=_entry_frame):
         assert _entry_frame is not None
         self._frame = frame
@@ -224,12 +226,11 @@ class FrameWrapper:
     @property
     def filename(self):
         return self._frame.f_code.co_filename
-    
+
     @property
     def lineno(self):
         return self._frame.f_lineno
 
-        
     def settrace(self, tracefn, stop=None):
         sys.settrace(tracefn)
         frame = self._frame
@@ -239,10 +240,9 @@ class FrameWrapper:
                 break
             frame = frame.f_back
         return frame
-    
+
     _calls_at_line: Dict[
-        Tuple[str, int],
-        Optional[bool],
+        Tuple[str, int], Optional[bool],
     ] = collections.defaultdict(lambda: None)
 
     def calls_function(self):
@@ -260,12 +260,11 @@ class FrameWrapper:
                     while (instruction := next(generator)).starts_line is None:
                         if "CALL" in instruction.opname:
                             self._calls_at_line[self] = True
-                            return True        
+                            return True
         except StopIteration:
             self._calls_at_line[self] = False
             return False
 
-
     def __str__(self):
         frame = self._frame
         string = super().__str__() + "\n"
@@ -273,13 +272,12 @@ class FrameWrapper:
             string += f"\t{frame.f_code.co_filename}:{frame.f_lineno}\n"
             frame = frame.f_back
         return string
-    
+
     def __hash__(self):
         return hash((self.frame.f_code.co_filename, self.frame.f_lineno))
 
 
 class QueueMGR:
-
     def __init__(self, mp_queue, factory, line_cache: LineCache) -> None:
         self._lock = threading.Lock()
         self._line_cache = line_cache
@@ -291,20 +289,17 @@ class QueueMGR:
         self._f_id = factory
 
         self._requests: Dict[
-            Tuple[str, str, int],
-            Union[Tuple[Condition, List[int]], list]
+            Tuple[str, str, int], Union[Tuple[Condition, List[int]], list]
         ] = {}
 
-
     def set_thread_ident(self, ident):
         with self._lock:
             self._thread_ident = ident
-    
+
     def clear_thread_ident(self):
         with self._lock:
             self._thread_ident = -1
 
-
     def post(self, key: Tuple[str, str, int]):
         self._requests[key] = [threading.Condition(), None]
 
@@ -316,7 +311,7 @@ class QueueMGR:
             lines = self._requests[key][1]
             del self._requests[key]
         return lines
-    
+
     def _start_fn(self):
         while self._running:
             try:
@@ -331,7 +326,7 @@ class QueueMGR:
                     with cond:
                         self._requests[key][1] = self._line_cache[key]
                         cond.notify_all()
-                
+
                 if data.event == "call":
                     logger.debug(f"call: {data.funcname}")
                 elif data.event == "return":
@@ -346,11 +341,16 @@ class QueueMGR:
 
 
 class ProcessFactory:
-
-    def __new__(cls, frame: FrameWrapper, func: Callable, stop: Any, continue_fn: Callable=None):
-        ipc = multiprocessing.Queue() # type: ignore
+    def __new__(
+        cls,
+        frame: FrameWrapper,
+        func: Callable,
+        stop: Any,
+        continue_fn: Callable = None,
+    ):
+        ipc = multiprocessing.Queue()  # type: ignore
         cond = multiprocessing.Condition()
-        
+
         # First fork saves the context of 'frame' before we enter a function
         # at the debugger.
         # TODO Don't fork if there isn't a function call at current line.
@@ -362,17 +362,17 @@ class ProcessFactory:
                 # Wait for parent to signal this process.
                 os.kill(pid, signal.SIGSTOP)
                 time.sleep(0.01)
-                child, _ = pty.fork() # Don't inherit stdin/stdout descriptors
+                child, _ = pty.fork()  # Don't inherit stdin/stdout descriptors
                 if child == 0:
                     # Second fork starts execution from saved context. A child
                     # is created on every step. The last child created is killed
                     time.sleep(0.01)
-                    # Install trace handlers                  
+                    # Install trace handlers
                     if continue_fn is not None:
                         continue_fn()
 
-                    trace = trace_create(pid, ipc)                  
-                    return func(frame.settrace(trace, stop))         
+                    trace = trace_create(pid, ipc)
+                    return func(frame.settrace(trace, stop))
                 else:
                     if last_child != -1:
                         os.kill(last_child, signal.SIGTERM)
@@ -381,14 +381,14 @@ class ProcessFactory:
                         status = -1
                     logger.info(
                         f"\n\tFactory ({pid}) stack level {frame.stack_level}: "
-                            f"{frame.filename}:{frame.lineno}"
+                        f"{frame.filename}:{frame.lineno}"
                         f"\n\t-> Fork: {child}"
                         f"\n\t Kill: {last_child} status: {status}\n"
                     )
                     last_child = child
                     continue
         else:
-            cache = defaultdict(list) # type: ignore
+            cache = defaultdict(list)  # type: ignore
             obj = super().__new__(cls)
             # __init__()
             obj._frame = frame
@@ -416,7 +416,7 @@ class ProcessFactory:
 
             self.queue.post(key)
             os.kill(self.pid, signal.SIGCONT)
-            
+
             def _start_fn():
                 time.sleep(1)
                 self.line_cache[key] = lines = self.queue.wait(key)
@@ -429,18 +429,14 @@ class ProcessFactory:
                     self._draw_graph(frame.frame, lines)
                     time.sleep(1)
 
-            thrd = threading.Thread(
-                target=_start_fn,
-                daemon=True,
-            )
+            thrd = threading.Thread(target=_start_fn, daemon=True,)
             thrd.start()
             self.thrd_ident = thrd.ident
-            
 
     def terminate(self) -> int:
         os.kill(self.pid, signal.SIGTERM)
         os.kill(self.pid, signal.SIGCONT)
-        _, status = os.waitpid(self.pid, 0)        
+        _, status = os.waitpid(self.pid, 0)
         self.queue.close()
         logger.info(
             f"\n\tKill {self.pid}"
@@ -449,33 +445,34 @@ class ProcessFactory:
             f"\n"
         )
         return status
-    
+
     @property
     def frame(self) -> FrameWrapper:
-        return self._frame # type: ignore
+        return self._frame  # type: ignore
 
     @property
     def stack_level(self) -> int:
-        return self._stack_level # type: ignore
-    
+        return self._stack_level  # type: ignore
+
     @property
     def pid(self) -> int:
-        return self._pid # type: ignore
+        return self._pid  # type: ignore
 
     @property
     def queue(self) -> QueueMGR:
-        return self._queue # type: ignore
+        return self._queue  # type: ignore
 
     @property
     def line_cache(self) -> LineCache:
-        return self._line_cache # type: ignore
+        return self._line_cache  # type: ignore
 
     nbuild = 0
-    def _draw_graph(self, frame, lst):        
+
+    def _draw_graph(self, frame, lst):
         name = frame.f_globals["__name__"]
         if frame.f_code.co_name != "<module>":
             name = f"{name}.{frame.f_code.co_name}"
-        
+
         key = frame.f_code.co_filename, frame.f_code.co_name
         cfg, context_blocks = cfg_db.at_function[key]
 
@@ -487,13 +484,10 @@ class ProcessFactory:
         self.nbuild += 1
 
 
-        
-     
-
-
 class ProcessStack(collections.deque):
     curr_stack_level: int = 0
-    base_factory: ProcessFactory = None # type: ignore
+    base_factory: ProcessFactory = None  # type: ignore
+
 
 _process_stack = ProcessStack()
 
@@ -534,11 +528,11 @@ def wrap_user_line(func, entry):
         if _pid == os.getpid() and _entry_frame is not None:
             frame = FrameWrapper(_frame)
             if frame.stack_level >= _process_stack.curr_stack_level:
-                if (factory := ProcessFactory(
-                    frame,
-                    functools.partial(func, dbg),
-                    dbg.botframe,
-                )) is None:
+                if (
+                    factory := ProcessFactory(
+                        frame, functools.partial(func, dbg), dbg.botframe,
+                    )
+                ) is None:
                     # Continue program execution from caller's stack frame.
                     return
 
@@ -547,18 +541,17 @@ def wrap_user_line(func, entry):
                     # if next step enters a higher stack level
                     _process_stack.appendleft(factory)
 
-                elif (_process_stack.curr_stack_level == frame.stack_level       
-                        and _process_stack[0] is None
+                elif (
+                    _process_stack.curr_stack_level == frame.stack_level
+                    and _process_stack[0] is None
                 ):
                     _process_stack[0] = factory
                     _process_stack.base_factory = ProcessFactory(
-                        frame,
-                        functools.partial(func, dbg),
-                        dbg.botframe,
+                        frame, functools.partial(func, dbg), dbg.botframe,
                     )
                     if _process_stack.base_factory is None:
                         # Continue program execution from first line of program
-                        return 
+                        return
 
                     cfg = CFGBuilder(short=True).build_from_file(name, entry)
                     cfg_db.index(entry, cfg)
@@ -570,8 +563,10 @@ def wrap_user_line(func, entry):
                             show=False,
                             calls=True,
                             cleanup=True,
-                            directory=os.path.join(os.environ["PY2CFG_SERVE_AT"], "cfg"),
-                            build_keys=False
+                            directory=os.path.join(
+                                os.environ["PY2CFG_SERVE_AT"], "cfg"
+                            ),
+                            build_keys=False,
                         )
                     except:
                         logger.warn("Failed to build cfg from source")
@@ -580,7 +575,9 @@ def wrap_user_line(func, entry):
                             json.dumps(
                                 {
                                     "type": "cfg",
-                                    "filepath": os.path.join("cfg", f"{name}.svg"),
+                                    "filepath": os.path.join(
+                                        "cfg", f"{name}.svg"
+                                    ),
                                     "layer": 0,
                                 }
                             )
@@ -604,18 +601,14 @@ def wrap_user_line(func, entry):
                     del _process_stack[0]
 
             if (k := (frame.filename, frame.lineno)) in cfg_db.at_lineno:
-                # When stopped at a functionDef statement, generate a 
+                # When stopped at a functionDef statement, generate a
                 # cfg with normal styling
                 subcfg, _ = cfg_db.at_lineno[k]
-                logger.warn(
-                    f"{str(subcfg)} @ {frame.filename}:{frame.lineno}"
-                )
+                logger.warn(f"{str(subcfg)} @ {frame.filename}:{frame.lineno}")
                 threading.Thread(
-                    target=dispatch_cfg,
-                    args=(subcfg,),
-                    daemon=True,
+                    target=dispatch_cfg, args=(subcfg,), daemon=True,
                 ).start()
-            
+
             elif (size := len(_process_stack)) > 1:
                 # Fork previous stack frame's factory
                 for i in range(1, size):
@@ -623,16 +616,17 @@ def wrap_user_line(func, entry):
                     if caller.stack_level < frame.stack_level:
                         caller.draw_graph(
                             frame,
-                            frame.stack_level > _process_stack.curr_stack_level
-                            )
+                            frame.stack_level > _process_stack.curr_stack_level,
+                        )
                         break
-  
+
             elif _process_stack.curr_stack_level == 0:
                 assert _process_stack.base_factory is not None
                 _process_stack.base_factory.draw_graph(frame, False)
 
-            _process_stack.curr_stack_level = frame.stack_level      
+            _process_stack.curr_stack_level = frame.stack_level
         return func(dbg, _frame)
+
     return user_line
 
 
@@ -645,7 +639,9 @@ def wrap_user_return(func, entry):
                     frame.f_code.co_filename, frame.f_code.co_name
                 ]
                 if subcfg.outline_block(frame.f_lineno, blocks) < 0:
-                    logger.warn(f"Failed to highlight block at {frame.f_lineno}")
+                    logger.warn(
+                        f"Failed to highlight block at {frame.f_lineno}"
+                    )
                 threading.Thread(
                     target=dispatch_cfg,
                     args=(subcfg, subcfg.name, True),
@@ -654,6 +650,7 @@ def wrap_user_return(func, entry):
 
             logger.debug(f"return: {frame.f_code.co_name}")
         return func(dbg, frame, return_value)
+
     return user_return
 
 
@@ -664,11 +661,10 @@ def wrap_user_exception(func, entry):
                 f"exception: {frame.f_code.co_filename}:{frame.f_lineno}"
             )
         return func(dbg, frame, exc_tuple)
+
     return user_exception
 
 
-
-
 class Handler(logging.Handler):
     def __init__(self, server):
         super().__init__()
@@ -693,7 +689,7 @@ def debug_init(debug_class, entryfile, port=None) -> None:
     _process_stack.appendleft(None)
 
     rootlog = logging.getLogger()
-    
+
     handler = Handler(server)
     rootlog.addHandler(handler)
     handler.setFormatter(logging.Formatter("%(asctime)s - %(message)s"))
@@ -704,14 +700,13 @@ def debug_init(debug_class, entryfile, port=None) -> None:
     # our own user_ functions.
     debug_class.user_call = wrap_user_call(debug_class.user_call, entryfile)
     debug_class.user_line = wrap_user_line(debug_class.user_line, entryfile)
-    debug_class.user_return = wrap_user_return(debug_class.user_return, entryfile)
+    debug_class.user_return = wrap_user_return(
+        debug_class.user_return, entryfile
+    )
     debug_class.user_exception = wrap_user_exception(
         debug_class.user_exception, entryfile
     )
-    threading.Thread(
-        target=server.run_forever,
-        daemon=True,
-    ).start()
+    threading.Thread(target=server.run_forever, daemon=True,).start()
 
     try:
         subprocess.Popen(["xdg-open", f"http://localhost:{port}"])
