@@ -60,7 +60,9 @@ def invert(
 
     if isinstance(node, ast.Compare):
         op = type(node.ops[0])
-        inverse_node: Union[ast.NameConstant, ast.UnaryOp, Compare] = ast.Compare(
+        inverse_node: Union[
+            ast.NameConstant, ast.UnaryOp, Compare
+        ] = ast.Compare(
             left=node.left, ops=[inverse[op]()], comparators=node.comparators
         )
     elif isinstance(node, ast.NameConstant) and node.value in [True, False]:
@@ -179,7 +181,7 @@ class CFGBuilder(ast.NodeVisitor):
 
         Returns:
             The CFG produced from the source code.
-        """ 
+        """
         tree = ast.parse(src, mode="exec")
         cfg = self.build(name, tree)
         cfg.lineno = 1
@@ -302,7 +304,7 @@ class CFGBuilder(ast.NodeVisitor):
             node.name, class_body, asynchr, self.current_id
         )
         classcfg.lineno = node.lineno
-        classcfg.end_lineno = node.end_lineno # type: ignore
+        classcfg.end_lineno = node.end_lineno  # type: ignore
         self.current_id = class_builder.current_id + 1
 
     def new_functionCFG(self, node: FunctionDef, asynchr: bool = False) -> None:
@@ -392,7 +394,9 @@ class CFGBuilder(ast.NodeVisitor):
                 elif "attr" in node.value._fields:
                     return visit_func(node.value)
                 else:
-                    raise AttributeError("WTF is this thing, build it in??", type(node))
+                    raise AttributeError(
+                        "WTF is this thing, build it in??", type(node)
+                    )
             elif isinstance(node, ast.Constant):
                 return node.value
             elif isinstance(node, ast.Call):
@@ -401,7 +405,9 @@ class CFGBuilder(ast.NodeVisitor):
                 elif "attr" in node.func._fields:
                     return visit_func(node.func)
                 else:
-                    raise AttributeError("WTF is this thing, build it in??", type(node))
+                    raise AttributeError(
+                        "WTF is this thing, build it in??", type(node)
+                    )
             else:
                 print("WTF is this thing, build it in??", type(node))
 
@@ -476,17 +482,23 @@ class CFGBuilder(ast.NodeVisitor):
                 #     control_transfer_here = True
                 # except Exception:
                 #     control_transfer_here = False
-                self.current_block.add_exit(tryobj.try_block.except_blocks[e_id])
+                self.current_block.add_exit(
+                    tryobj.try_block.except_blocks[e_id]
+                )
                 break
             elif contains(None, TryEnum.BODY):
                 # try:
                 #     raise StopIteration
                 # except:
                 #     control_transfers_here = 1
-                self.current_block.add_exit(tryobj.try_block.except_blocks[None])
+                self.current_block.add_exit(
+                    tryobj.try_block.except_blocks[None]
+                )
                 break
 
-            elif contains(e_id, TryEnum.EXCEPT) or contains(None, TryEnum.EXCEPT):
+            elif contains(e_id, TryEnum.EXCEPT) or contains(
+                None, TryEnum.EXCEPT
+            ):
                 if tryobj.has_final:
                     _after_block = self.new_block()
                     self.current_block.add_exit(_after_block)
@@ -711,7 +723,9 @@ class CFGBuilder(ast.NodeVisitor):
         try_block = self.new_try_block(node)
         after_tryblock = self.new_block()
         self.current_block.add_exit(try_block)
-        stackobj = TryStackObject(try_block, after_tryblock, bool(node.finalbody))
+        stackobj = TryStackObject(
+            try_block, after_tryblock, bool(node.finalbody)
+        )
         self.try_stack.appendleft(stackobj)
 
         stackobj.iter_state = TryEnum.EXCEPT
