@@ -54,7 +54,7 @@ class Block(object):
         self.highlight: bool = False
         # Debugger at this block
         self.outline: bool = False
-    
+
     def __iter__(self):
         return iter(self.statements)
 
@@ -165,7 +165,10 @@ class Link(object):
     )
 
     def __init__(
-        self, source: Block, target: Block, exitcase: Optional[ast.Compare] = None
+        self,
+        source: Block,
+        target: Block,
+        exitcase: Optional[ast.Compare] = None,
     ) -> None:
         assert isinstance(target, Block), "Source of a link must be a block"
         assert isinstance(target, Block), "Target of a link must be a block"
@@ -274,7 +277,9 @@ class CFG(object):
     }
     DEFAULT = node_styles["default"]
 
-    def __init__(self, name: str, asynchr: bool = False, short: bool = True) -> None:
+    def __init__(
+        self, name: str, asynchr: bool = False, short: bool = True
+    ) -> None:
         assert isinstance(name, str), "Name of a CFG must be a string"
         assert isinstance(asynchr, bool), "Async must be a boolean value"
         # Name of the function or module being represented.
@@ -295,14 +300,17 @@ class CFG(object):
         self.end_lineno: int = 0
         self.qualname = ""
 
-
     def __str__(self) -> str:
         return "CFG for {}".format(self.name)
 
     def _build_key_subgraph(self, format: str) -> Digraph:
-        # Generates a key for the CFG
+        # Generates a key for th?!?jedi=0, e CFG?!? (name=None, comment=None, filename=None, directory=None, format=None, engine=None, encoding=backend.ENCODING, graph_attr=None, node_attr=None, *_*edge_attr=None*_*, body=None, strict=False) ?!?jedi?!?
         key_subgraph = gv.Digraph(
-            name="cluster_KEY", format=format, graph_attr={"label": "KEY"}
+            name="cluster_KEY",
+            format=format,
+            graph_attr={"label": "KEY", "fontname": "DejaVu Sans Mono"},
+            node_attr={"fontname": "DejaVu Sans Mono"},
+            edge_attr={"fontname": "DejaVu Sans Mono"},
         )
         for typeobj, (shape, color) in zip(
             self.node_styles.keys(), self.node_styles.values()
@@ -313,7 +321,11 @@ class CFG(object):
                     if isinstance(typeobj, type)
                     else str(typeobj)
                 ),
-                _attributes={"shape": shape, "style": "filled", "fillcolor": color},
+                _attributes={
+                    "shape": shape,
+                    "style": "filled",
+                    "fillcolor": color,
+                },
             )
 
         # Adding edge helps with alignment.
@@ -325,7 +337,9 @@ class CFG(object):
         return key_subgraph
 
     # default handler for graph nodes
-    def _style_handler(self, block: Block, typeobject: Any) -> Tuple[str, str, str]:
+    def _style_handler(
+        self, block: Block, typeobject: Any
+    ) -> Tuple[str, str, str]:
 
         shape, color = self.node_styles.get(typeobject, self.DEFAULT)
         # Left-align all remaining blocks
@@ -341,9 +355,15 @@ class CFG(object):
         # implement handlers. This should allow us to implement new node types
         # simply defining a method `node_ASTNAME`
         typeobject = block.type(default)
-        name = typeobject.__name__ if isinstance(typeobject, type) else typeobject
-        style = getattr(self, f"node_{name}", self._style_handler)(block, typeobject)
-        assert len(style) == 3, "Style handler must return (shape, color, label)"
+        name = (
+            typeobject.__name__ if isinstance(typeobject, type) else typeobject
+        )
+        style = getattr(self, f"node_{name}", self._style_handler)(
+            block, typeobject
+        )
+        assert (
+            len(style) == 3
+        ), "Style handler must return (shape, color, label)"
         assert all(
             isinstance(attr, str) or attr or attr is None for attr in style
         ), "Style attributes must be str or NoneType"
@@ -353,7 +373,9 @@ class CFG(object):
         self, link: Link, default: None = None, default_target: None = None
     ) -> tuple:
         typeobject = link.source.type(default)
-        name = typeobject.__name__ if isinstance(typeobject, type) else typeobject
+        name = (
+            typeobject.__name__ if isinstance(typeobject, type) else typeobject
+        )
         target_type = link.target.type(default_target)
         target_name = (
             target_type.__name__ if isinstance(typeobject, type) else typeobject
@@ -365,7 +387,9 @@ class CFG(object):
         if style_fn is None:
             style_fn = getattr(self, f"edge_{name}", self._edge_handler)
         style = style_fn(link)
-        assert len(style) == 3, "style handler must return (shape, color, label)"
+        assert (
+            len(style) == 3
+        ), "style handler must return (shape, color, label)"
         assert all(
             isinstance(attr, str) or attr is None for attr in style
         ), "style attributes must be str or NoneType"
@@ -400,7 +424,7 @@ class CFG(object):
         visited: Set[Block] = set(),
         calls: bool = True,
         format: str = None,
-        interactive: bool = False
+        interactive: bool = False,
     ) -> None:
         # Don't visit blocks twice.
         if block in visited:
@@ -424,7 +448,9 @@ class CFG(object):
                               (\"|')"""  # Group 4: " or '
             original_nodelabel = original_nodelabel.replace("\l", "\n")
             for line in original_nodelabel.splitlines():
-                tmp_line = re.sub(sub_pattern, r"\1\2...\4", line, flags=re.VERBOSE)
+                tmp_line = re.sub(
+                    sub_pattern, r"\1\2...\4", line, flags=re.VERBOSE
+                )
                 nodelabel += tmp_line + "\l"
         else:
             nodelabel = original_nodelabel
@@ -459,9 +485,12 @@ class CFG(object):
                     "style": "filled",
                     "color": self.fillcolor(block, interactive, "purple"),
                     "compound": "true",
+                    "fontname": "DejaVu Sans Mono",
                     "shape": self.node_styles[ast.Call][0],
                     "label": "",
                 },
+                node_attr={"fontname": "DejaVu Sans Mono"},
+                edge_attr={"fontname": "DejaVu Sans Mono"},
             )
             # Generate control flow edges for function arguments
             for func_block in block.func_blocks:
@@ -490,7 +519,9 @@ class CFG(object):
                         _attributes={
                             "style": f"filled,{self.border_style(block, interactive)}",
                             "shape": nodeshape,
-                            "fillcolor": self.fillcolor(block, interactive, nodecolor),
+                            "fillcolor": self.fillcolor(
+                                block, interactive, nodecolor
+                            ),
                         },
                     )
                     graph.edge(input_node, str(block.id))  # yellow
@@ -521,7 +552,13 @@ class CFG(object):
 
     subgraphs: dict = Counter()
 
-    def _build_visual(self, format: str = "pdf", calls: bool = True, interactive: bool = False, build_own=False) -> Digraph:
+    def _build_visual(
+        self,
+        format: str = "pdf",
+        calls: bool = True,
+        interactive: bool = False,
+        build_own=False,
+    ) -> Digraph:
         graph = gv.Digraph(
             name=f"cluster{self.subgraphs[self.name]}{self.name}",
             format=format,
@@ -529,13 +566,18 @@ class CFG(object):
                 "label": self.name,
                 "rankdir": "TB",
                 "ranksep": "0.02",
+                "fontname": "DejaVu Sans Mono",
                 "compound": "True",
                 "pack": "False",
             },
+            node_attr={"fontname": "DejaVu Sans Mono"},
+            edge_attr={"fontname": "DejaVu Sans Mono"},
         )
         self.subgraphs[self.name] += 1
         if self.entryblock is None:
-            raise TypeError("Expected self.entryblock to be not None but type is None")
+            raise TypeError(
+                "Expected self.entryblock to be not None but type is None"
+            )
         self._visit_blocks(
             graph,
             self.entryblock,
@@ -550,21 +592,16 @@ class CFG(object):
         # them to the graph.
         for subcfg in self.classcfgs:
             subgraph = self.classcfgs[subcfg]._build_visual(
-                format=format,
-                calls=calls,
-                interactive=interactive,
+                format=format, calls=calls, interactive=interactive,
             )
             graph.subgraph(subgraph)
 
         for subcfg in self.functioncfgs:
             subgraph = self.functioncfgs[subcfg]._build_visual(
-                format=format,
-                calls=calls,
-                interactive=interactive,
+                format=format, calls=calls, interactive=interactive,
             )
             graph.subgraph(subgraph)
         return graph
-    
 
     @staticmethod
     def border_style(block: Block, interactive: bool):
@@ -572,9 +609,11 @@ class CFG(object):
             return "bold" if block.outline else "dashed"
         else:
             return "solid"
-    
+
     @staticmethod
-    def fillcolor(block: Block, interactive: bool, color: str, default: str = ""):
+    def fillcolor(
+        block: Block, interactive: bool, color: str, default: str = ""
+    ):
         if interactive:
             if block.highlight:
                 return color
@@ -583,11 +622,10 @@ class CFG(object):
         else:
             return color
 
-
     def build_key(self, **kwargs):
         """Build key graph"""
         key = self._build_key_subgraph(kwargs.get("format", "svg"))
-        return key.render(**kwargs)    
+        return key.render(**kwargs)
 
     def build_visual(
         self,
@@ -600,7 +638,7 @@ class CFG(object):
         interactive=False,
         build_keys=True,
         build_own=False,
-        diffable=None
+        diffable=None,
     ) -> str:
         """
         Build a visualisation of the CFG with graphviz and output it in a DOT
@@ -625,8 +663,9 @@ class CFG(object):
         graph = self._build_visual(format, calls, interactive, build_own)
         if build_keys:
             graph.subgraph(self._build_key_subgraph(format))
-        return graph.render(filepath, view=show, cleanup=cleanup, directory=directory)
-
+        return graph.render(
+            filepath, view=show, cleanup=cleanup, directory=directory
+        )
 
     def __iter__(self) -> Iterator[Block]:
         """
@@ -647,7 +686,9 @@ class CFG(object):
         """
         visited = set()
         if self.entryblock is None:
-            raise TypeError("Expected self.entryblock to be not None but type is None")
+            raise TypeError(
+                "Expected self.entryblock to be not None but type is None"
+            )
         to_visit: Deque[Block] = deque([self.entryblock])
         while to_visit:
             block = to_visit.popleft()
@@ -658,7 +699,9 @@ class CFG(object):
                 to_visit.append(exit_.target)
             yield block
 
-    def node_ClassDef(self, block: Block, typeobj: type) -> Tuple[str, str, str]:
+    def node_ClassDef(
+        self, block: Block, typeobj: type
+    ) -> Tuple[str, str, str]:
         text = block.get_source().splitlines()[0] + "...\n"
         return (*self.node_styles.get(typeobj, self.DEFAULT), text)
 
@@ -692,7 +735,9 @@ class CFG(object):
             color = "green"
         return None, color, edgelabel
 
-    def bsearch(self, lineno: int, lst:Optional[list] = None) -> Optional[Block]:
+    def bsearch(
+        self, lineno: int, lst: Optional[list] = None
+    ) -> Optional[Block]:
         """Search for a block at line"""
 
         def _bsearch(lst, low, high, line):
@@ -719,41 +764,41 @@ class CFG(object):
         self.outlined_block.outline = False
         if (block := self.bsearch(lineno, lst)) is None:
             return -1
-        self.outlined_block = block #type: ignore
-        block.outline = True #type: ignore
+        self.outlined_block = block  # type: ignore
+        block.outline = True  # type: ignore
         return 0
 
-
     def highlight_blocks(self, lines, blocks=None) -> int:
         """In interactive mode, highlight the block at lineno"""
         for block in self.highlighted_blocks:
             block.highlight = False
-        
+
         highlighted_blocks: List[Block] = []
         for line in list(lines):
-            if (block := self.bsearch(line, blocks)) is not None: #type: ignore
+            if (block := self.bsearch(line, blocks)) is not None:  # type: ignore
                 block.highlight = True
                 highlighted_blocks.append(block)
-            
+
         self.highlighted_blocks = highlighted_blocks
         return 0
 
     def find_path(self, finalblock: Block) -> Deque[Link]:
         if self.entryblock is None:
             raise ValueError("entryblock cannot be none")
-        
+
         assert finalblock in self.finalblocks
         visited: Set[Block] = set()
         path: Deque[Link] = collections.deque()
+
         def _find_path(link: Link):
             blk: Block = link.target
             if blk in visited:
                 return False
-            
+
             visited.add(blk)
             if blk == finalblock:
                 return True
-            
+
             for lk in blk.exits:
                 path.append(lk)
                 if _find_path(lk):
@@ -765,7 +810,7 @@ class CFG(object):
             if _find_path(lk):
                 return path
             path.pop()
-        
+
         # TODO find all possible paths from entry to final and return set
         # TODO find path from any line to any line
-        return collections.deque()
\ No newline at end of file
+        return collections.deque()
