@@ -7,15 +7,12 @@ from .util import getcwd
 
 parser = argparse.ArgumentParser()
 runner_path = os.path.join(
-    os.path.dirname(os.path.abspath(__file__)),
-    "_runner.py"
+    os.path.dirname(os.path.abspath(__file__)), "_runner.py"
 )
-parser.add_argument("host", nargs='?', type=str, default="localhost")
-parser.add_argument("port", nargs='?', type=str, default="5000")
+parser.add_argument("host", nargs="?", type=str, default="localhost")
+parser.add_argument("port", nargs="?", type=str, default="5000")
 
-parser.add_argument(
-    "--directory", type=str, default="."
-)
+parser.add_argument("--directory", type=str, default=".")
 parser.add_argument(
     "--logconf-port", type=int, default=8123,
 )
@@ -31,4 +28,4 @@ if not os.path.exists(tmpdir := os.path.join(getcwd(), ".py2cfg")):
 
 logging.config.listen(args.logconf_port).start()
 os.environ["FLASK_APP"] = runner_path
-subprocess.call(["flask", "run", "-h", args.host, "-p", args.port])
\ No newline at end of file
+subprocess.call(["flask", "run", "-h", args.host, "-p", args.port])
